import React from 'react';
import { LinkProps, NavigateProps } from 'react-router-dom';
import { CheckParamReq, ExtractParams, Pattern, RoutePattern, To, TypedPathMatch, TypedPathPattern } from './types';
import { TypedNavigateFunction } from './useTypedNavigate';
export interface TypedLinkProps<RoutePattern extends string> extends Omit<LinkProps, 'to' | 'replace'> {
    to: To<RoutePattern>;
    params: ExtractParams<RoutePattern>;
}
export interface TypedNavigateProps<RoutePattern extends string> extends Omit<NavigateProps, 'to' | 'replace'> {
    to: To<RoutePattern>;
    params: ExtractParams<RoutePattern>;
}
interface TypedRouter<RoutesType extends string> {
    Link<Pattern extends RoutesType>(props: CheckParamReq<TypedLinkProps<Pattern>>): React.ReactElement;
    Navigate<Pattern extends RoutesType>(props: CheckParamReq<TypedNavigateProps<Pattern>>): React.ReactElement;
    useMatch: (pattern: Pattern<RoutesType>) => TypedPathMatch<RoutePattern<RoutesType>, ExtractParams<RoutePattern<RoutesType>>>;
    useNavigate: () => TypedNavigateFunction<RoutesType>;
    matchPath: (pattern: TypedPathPattern<RoutesType>, pathname: string) => TypedPathMatch<RoutesType, ExtractParams<RoutesType>>;
    generatePath<Pattern extends RoutesType>(path: Pattern, params: ExtractParams<Pattern>): string;
}
export declare const constructTypedRouter: <T>(routes: T) => TypedRouter<RoutePattern<T> & string>;
export {};
